# TODO:
# - iscsi: libiscsi.h, libiscsi_init in libiscsi
# - lsm: libstoragemgmt >= 1.3.0, libconfig >= 1.3.2
#
# Conditional build:
%bcond_with	elogind		# elogind
%bcond_with	iscsi		# iSCSI support
%bcond_with	libstoragemgmt	# libstoragemgmt support
%bcond_without	apidocs		# do not build and package API docs
%bcond_without	static_libs	# don't build static libraries

Summary:	Disk Management Service
Summary(pl.UTF-8):	Usługa zarządzania dyskami
Name:		udisks2
Version:	2.8.4
Release:	1
License:	GPL v2+
Group:		Libraries
#Source0Download: https://github.com/storaged-project/udisks/releases
Source0:	https://github.com/storaged-project/udisks/releases/download/udisks-%{version}/udisks-%{version}.tar.bz2
# Source0-md5:	ee74a32fe2a7ab3dd3aa9e2283b844ea
Patch0:		automake-1.12.patch
URL:		https://www.freedesktop.org/wiki/Software/udisks
BuildRequires:	acl-devel
BuildRequires:	autoconf >= 2.50
BuildRequires:	automake >= 1:1.11
%{?with_elogind:BuildRequires:	elogind-devel >= 219}
BuildRequires:	gettext-tools >= 0.19.8
BuildRequires:	glib2-devel >= 1:2.50
BuildRequires:	gobject-introspection-devel >= 0.6.2
BuildRequires:	gtk-doc >= 1.3
BuildRequires:	libatasmart-devel >= 0.17
# with btrfs,crypto,fs,kbd,loop,lvm2,mdraid,part,swap,vdo modules
BuildRequires:	libblockdev-devel >= 2.19
%{?with_libstoragemgmt:BuildRequires:	libconfig-devel >= 1.3.2}
BuildRequires:	libmount-devel >= 2.30
%{?with_libstoragemgmt:BuildRequires:	libstoragemgmt-devel >= 1.3.0}
BuildRequires:	libtool
BuildRequires:	libxslt-progs
BuildRequires:	pkgconfig
BuildRequires:	polkit-devel >= 0.102
%{!?with_elogind:BuildRequires:	systemd-devel >= 1:209}
BuildRequires:	udev-glib-devel >= 1:165
%{?with_elogind:BuildConflicts:	systemd-devel}
Requires:	%{name}-libs = %{version}-%{release}
Requires:	libatasmart >= 0.17
Requires:	systemd-units >= 44
Requires:	udev-core >= 1:147
Requires:	udev-glib >= 1:165
Suggests:	acl
Suggests:	cryptsetup-luks
Suggests:	dosfstools
Suggests:	e2fsprogs
Suggests:	gdisk
Suggests:	losetup
Suggests:	mount
Suggests:	nilfs-utils
Suggests:	ntfsprogs
Suggests:	parted
Suggests:	reiserfsprogs
Suggests:	util-linux
Suggests:	xfsprogs
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
udisks provides a daemon, D-Bus API and command line tools for
managing disks and storage devices. This package is for the udisks 2.x
series.

%description -l pl.UTF-8
udisks dostarcza demona, API D-Bus oraz narzędzia linii poleceń do
zarządzania dyskami i innymi urządzeniami przechowującymi dane. Ten
pakiet jest przeznaczony dla udisks z serii 2.x.

%package libs
Summary:	udisks2 library
Summary(pl.UTF-8):	Biblioteka udisks2
License:	LGPL v2+
Group:		Libraries
Requires:	glib2 >= 1:2.50

%description libs
This package contains udisks2 library, which provides access to the
udisks daemon.

%description libs -l pl.UTF-8
Ten pakiet zawiera bibliotekę udisks2, umożliwiającą dostęp do demona
udisks.

%package devel
Summary:	Header files for udisks2 library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki udisks2
License:	LGPL v2+
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	glib2-devel >= 1:2.50

%description devel
Header files for udisks2 library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki udisks2.

%package static
Summary:	Static udisks2 library
Summary(pl.UTF-8):	Statyczna biblioteka udisks2
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static udisks2 library.

%description static -l pl.UTF-8
Statyczna biblioteka udisks2.

%package apidocs
Summary:	udisks2 API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki udisks2
Group:		Documentation
Requires:	gtk-doc-common
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API documentation for udisks2 library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki udisks2.

%package -n bash-completion-udisks2
Summary:	bash-completion for udisks2
Summary(pl.UTF-8):	Bashowe uzupełnianie parametrów dla udisks2
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	bash-completion >= 2
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description -n bash-completion-udisks2
This package provides bash-completion for udisks2 (udisksctl command).

%description -n bash-completion-udisks2 -l pl.UTF-8
Pakiet ten dostarcza bashowe uzupełnianie parametrów dla udisks2
(polecenia udisksctl).

%prep
%setup -q -n udisks-%{version}
%patch0 -p1

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{__enable_disable apidocs gtk-doc} \
	--enable-available-modules \
	%{__enable_disable static_libs static} \
	--disable-silent-rules \
	--with-html-dir=%{_gtkdocdir} \
	--with-systemdsystemunitdir=%{systemdunitdir}
%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} $RPM_BUILD_ROOT%{_libdir}/*.la
%{__rm} $RPM_BUILD_ROOT%{_libdir}/udisks2/modules/*.la
%if %{with static_libs}
%{__rm} $RPM_BUILD_ROOT%{_libdir}/udisks2/modules/*.a
%endif

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS NEWS README.md
%attr(755,root,root) %{_bindir}/udisksctl
%attr(755,root,root) %{_sbindir}/umount.udisks2
%dir %{_libexecdir}/udisks2
%attr(755,root,root) %{_libexecdir}/udisks2/udisksd
%if "%{_libdir}" != "%{_libexecdir}"
%dir %{_libdir}/udisks2
%endif
%dir %{_libdir}/udisks2/modules
%attr(755,root,root) %{_libdir}/udisks2/modules/libudisks2_bcache.so
%attr(755,root,root) %{_libdir}/udisks2/modules/libudisks2_btrfs.so
%attr(755,root,root) %{_libdir}/udisks2/modules/libudisks2_lvm2.so
%attr(755,root,root) %{_libdir}/udisks2/modules/libudisks2_vdo.so
%attr(755,root,root) %{_libdir}/udisks2/modules/libudisks2_zram.so
%dir %{_sysconfdir}/udisks2
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/udisks2/udisks2.conf
/lib/udev/rules.d/80-udisks2.rules
%{systemdunitdir}/clean-mount-point@.service
%{systemdunitdir}/udisks2.service
%{systemdunitdir}/zram-setup@.service
%{systemdtmpfilesdir}/udisks2.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.UDisks2.service
%{_datadir}/dbus-1/system.d/org.freedesktop.UDisks2.conf
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.policy
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.bcache.policy
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.btrfs.policy
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.lvm2.policy
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.vdo.policy
%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.zram.policy
%{_mandir}/man1/udisksctl.1*
%{_mandir}/man5/udisks2.conf.5*
%{_mandir}/man8/udisks.8*
%{_mandir}/man8/udisksd.8*
%{_mandir}/man8/umount.udisks2.8*
%attr(700,root,root) %dir /var/lib/udisks2

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libudisks2.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libudisks2.so.0
%{_libdir}/girepository-1.0/UDisks-2.0.typelib

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libudisks2.so
%{_datadir}/gir-1.0/UDisks-2.0.gir
%{_includedir}/udisks2
%{_pkgconfigdir}/udisks2.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libudisks2.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/udisks2
%endif

%files -n bash-completion-udisks2
%defattr(644,root,root,755)
%{bash_compdir}/udisksctl
%changelog
* Fri Nov 01 2019 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/udisks2.git;a=log;h=master

* Sun Oct 27 2019 Jakub Bogusz <qboosh@pld-linux.org> 5b7f8d8
- new URLs, updated to 2.8.4

* Mon May 20 2019 Jakub Bogusz <qboosh@pld-linux.org> 3618e35
- updated to 2.1.8

* Fri Jul 03 2015 Jakub Bogusz <qboosh@pld-linux.org> 6bcfdc7
- updated udisksd path
- release 3

* Thu Jul 02 2015 Elan Ruusamäe <glen@delfi.ee> 02b17b8
- noarch apidocs

* Wed Jul 01 2015 Jakub Bogusz <qboosh@pld-linux.org> 5c099c3
- updated to 2.1.6

* Mon Mar 09 2015 Łukasz Kieś <kiesiu@pld-linux.org> 2917db9
- updated to 2.1.5

* Mon Mar 02 2015 Łukasz Kieś <kiesiu@pld-linux.org> 4ce4b6b
- minumum version of systemd required is 44; rel. 2

* Sun Dec 28 2014 Jan Rękorajski <baggins@pld-linux.org> c15f051
- updated gettext BR

* Thu Dec 25 2014 Jakub Bogusz <qboosh@pld-linux.org> f9cffd2
- systemd epoch

* Mon Dec 22 2014 Łukasz Kieś <kiesiu@pld-linux.org> 6249313
- updated to 2.1.4
- updated BRs, Rs and files

* Sat Mar 15 2014 Elan Ruusamäe <glen@delfi.ee> ccd10e2
- noarch bash completions

* Tue Mar 11 2014 Jakub Bogusz <qboosh@pld-linux.org> ec4768c
- updated to 2.1.3 (fixes CVE-2014-0004)

* Wed Jan 15 2014 Łukasz Kieś <kiesiu@pld-linux.org> 6bce7b1
- updated to 2.1.2

* Sun Sep 29 2013 Jakub Bogusz <qboosh@pld-linux.org> aec8bf9
- updated to 2.1.1
- pl

* Wed Mar 20 2013 Łukasz Kieś <kiesiu@pld-linux.org> 674fc2e
- updated to 2.1.0 (stable API)

* Thu Jan 03 2013 Łukasz Kieś <kiesiu@pld-linux.org> aacce59
- updated to 2.0.1

* Mon Oct 22 2012 Łukasz Kieś <kiesiu@pld-linux.org> 5e42ad8
- updated to 2.0.0
- patch1 fixed upstream

* Mon Oct 22 2012 Łukasz Kieś <kiesiu@pld-linux.org> 8a277af
- obsoleted

* Mon Aug 13 2012 Jan Rękorajski <baggins@pld-linux.org> d37361b
- Fix fedora/systemd monoculture stupidity

* Mon Jul 30 2012 Łukasz Kieś <kiesiu@pld-linux.org> 7b1dc45
- updated to 1.99.0

